module.exports = function(grunt) {

    require('load-grunt-tasks')(grunt);
    require('time-grunt')(grunt);

    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),

        htmlhint: {
            options: {
                'attr-lower-case': true,
                'attr-value-not-empty': false,
                'tag-pair': true,
                'tag-self-close': false,
                'tagname-lowercase': true,
                'id-class-value': true,
                'id-unique': true,
                'img-alt-require': true,
                'img-alt-not-empty': true
            },
            main: {
                src: ['public/**.html']
            }
        },

        jshint: {
            main: {
                files: [{
                    src: ['Gruntfile.js', 'js/**/*.js']
                }]
            },
            options: {
                globals: {
                    'jQuery': true,
                    'console': true
                }
            }
        },

        pug: {
            options: {
                pretty: true,
                data: {
                    debug: true
                }
            },
            pages: {
                files: [{
                    expand: true,
                    cwd: 'pug/pages',
                    src: '*.pug',
                    dest: 'public/',
                    ext: '.html'
                }]
            }
        },

        copy: {
            iejs: {
                expand: true,
                files: [{
                        expand: true,
                        cwd: 'node_modules/html5shiv/dist',
                        src: "**",
                        dest: 'public/js'
                    },
                    {
                        expand: true,
                        cwd: 'node_modules/Respond.js/src',
                        src: "**",
                        dest: 'public/js'
                    }
                ]
            },
            lfltcss: {
                expand: true,
                files: [{
                    expand: true,
                    cwd: 'node_modules/leaflet/dist/images',
                    src: "**",
                    dest: 'public/img'
                }]
            },
            fonts: {
                expand: true,
                files: [{
                    expand: true,
                    cwd: 'fonts',
                    src: "**",
                    dest: 'public/fonts'
                }]
            },
            imgrsrc: {
                expand: true,
                files: [{
                    expand: true,
                    cwd: 'img',
                    src: "**",
                    dest: 'public/img'
                }]
            }
        },

        uglify: {
            compress: {
                files: {
                    'public/js/index.js': [
                        //'node_modules/jquery/dist/jquery.min.js',
                        //'node_modules/bootstrap/dist/js/bootstrap.min.js',
                        'node_modules/leaflet/dist/leaflet.js',
                        'js/*.js'
                    ]
                },
                options: {
                    mangle: true,
                    unused: true
                }
            }
        },

        cssmin: {
            options: {
                sourceMap: true
            },
            compress: {
                files: {
                    'public/css/index.css': [
                        'node_modules/bootstrap/dist/css/bootstrap.min.css',
                        //'node_modules/font-awesome/css/font-awesome.min.css',
                        //'node_modules/normalize.css/normalize.css',
                        'node_modules/leaflet/dist/leaflet.css',
                        'css/*.css'
                    ]
                }
            }
        },

        watch: {
            grunt: {
                files: ['Gruntfile.js'],
                options: {
                    nospawn: true,
                    keepalive: true,
                    livereload: true
                },
                tasks: ['public:dev']
            },
            html: {
                files: ['public/*.html'],
                options: {
                    nospawn: true,
                    keepalive: true,
                    livereload: true
                },
                tasks: ['htmlhint']
            },
            js: {
                files: 'js/**',
                options: {
                    nospawn: true,
                    livereload: true
                },
                tasks: ['jshint', 'uglify']
            },
            pug: {
                files: ['pug/**'],
                options: {
                    nospawn: true,
                    livereload: true
                },
                tasks: ['pug']
            },
           css: {
               files: 'css/**',
               options: {
                   nospawn: true,
                   livereload: true
               },
               tasks: ['cssmin']
           }
        },

        connect: {
            server: {
                options: {
                    port: 8080,
                    base: 'public',
                    hostname: 'localhost',
                    livereload: true
                }
            }
        }

    });

    grunt.registerTask('public:dev', function(target) {
        grunt.task.run([
            'pug',
            'htmlhint',
            'jshint',
            'copy',
            'uglify',
            'cssmin'
        ]);
    });

    grunt.registerTask('serve', function(target) {
        grunt.task.run([
            'public:dev',
            'connect',
            'watch'
        ]);
    });

};
